==> smart-testauto-framework-1.0.3-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/validator/mechanisms/RowSelectionMechanism.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.validator.mechanisms;

/**
 * 
 * @author Madhav Krishna
 *
 */
public class RowSelectionMechanism {
	private SelectionMechanism selectionMechanism;
	private Integer columnIndex;

	public static enum SelectionMechanism {
		clickRowCell, doubleClickRowCell, ctrlClickRowCellForMultiSelect
	};

	/**
	 * 
	 * @param mechanism
	 *            Mechanism used to select the row in a grid or combobox.
	 */
	public RowSelectionMechanism(SelectionMechanism mechanism) {
		this.selectionMechanism = mechanism;
		this.columnIndex = 0;
	}
	
	/**
	 * 
	 * @param mechanism
	 *            Mechanism used to select the row in a grid or combobox.
	 * @param columnIndex
	 *            Column index at which the selection mechanism will get
	 *            applied.
	 */
	public RowSelectionMechanism(SelectionMechanism mechanism,
			Integer columnIndex) {
		this.selectionMechanism = mechanism;
		this.columnIndex = columnIndex;
	}

	public SelectionMechanism getSelectionMechanism() {
		return selectionMechanism;
	}

	public Integer getColumnIndex() {
		return columnIndex;
	}
}

==> smart-testauto-framework-2.0.1-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/validator/mechanisms/RowSelectionMechanism.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.validator.mechanisms;

/**
 * 
 * @author Madhav Krishna
 *
 */
public class RowSelectionMechanism {
	private SelectionMechanism selectionMechanism;
	private Integer columnIndex;

	public static enum SelectionMechanism {
		clickRowCell, doubleClickRowCell, ctrlClickRowCellForMultiSelect
	};

	/**
	 * 
	 * @param mechanism Mechanism used to select the row in a grid or combobox.
	 */
	public RowSelectionMechanism(SelectionMechanism mechanism) {
		this.selectionMechanism = mechanism;
		this.columnIndex = 0;
	}

	/**
	 * 
	 * @param mechanism   Mechanism used to select the row in a grid or combobox.
	 * @param columnIndex Column index at which the selection mechanism will get
	 *                    applied.
	 */
	public RowSelectionMechanism(SelectionMechanism mechanism, Integer columnIndex) {
		this.selectionMechanism = mechanism;
		this.columnIndex = columnIndex;
	}

	public SelectionMechanism getSelectionMechanism() {
		return selectionMechanism;
	}

	public Integer getColumnIndex() {
		return columnIndex;
	}
}
